Functions related to adding and removing indentation from lines of text.
Functions
- dedent
- Removes common leading whitespace from each line.
- dedent_
to - Reduce a block’s indentation to match the provided indentation.
- indent
- Indent each line by the given prefix.
- indent_
first_ line - Indent only the first line by the given prefix.