pub fn first_non_trivia_token(
offset: TextSize,
code: &str,
) -> Option<SimpleToken>Expand description
Searches for the first non-trivia character after offset.
The search skips over any whitespace and comments.
Returns Some if the source code after offset contains any non-trivia character.///
Returns None if the text after offset is empty or only contains trivia (whitespace or comments).