Module textwrap

Module textwrap 

Functions related to adding and removing indentation from lines of text.

Functions

dedent
Removes common leading whitespace from each line.
dedent_to
Reduce a block’s indentation to match the provided indentation.
indent
Indent each line by the given prefix.
indent_first_line
Indent only the first line by the given prefix.